package com.nx.umms.common.utils.res;

import com.nx.umms.common.utils.BeagleStringUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestControllerAdvice;

/**
 * @Auther: wangjian
 * @Date: 2022/3/28 17:42
 * @Description:全局异常处理器
 */
@Slf4j
@RestControllerAdvice
public class OverallExceptionHandler {

    /**
     * 默认全局异常处理。
     *
     * @param exception
     * @return ResultData
     */
    @ExceptionHandler(Exception.class)
    @ResponseStatus(HttpStatus.INTERNAL_SERVER_ERROR)
    public ResultVO<String> exception(Exception exception) {
        log.error("全局异常信息 ex={}", exception.getMessage(), exception);
        return ResultVO.fail(ResultCodeEnum.INTERNAL_SERVER_ERROR, exception.getMessage());
    }

    /**
     * 业务异常处理。
     *
     * @param businessException
     * @return ResultData
     */
    @ExceptionHandler(value = BusinessException.class)
    public ResultVO beagleExceptionHandler(BusinessException businessException) {
        log.error("发生业务异常！原因是：{}", businessException.getErrorMessage());
        ResultVO resultVO = new ResultVO();
        if (BeagleStringUtils.isBlank(businessException.getErrorMessage())) {
            resultVO.setResultCodeEnum(ResultCodeEnum.INTERNAL_SERVER_ERROR);
        } else {
            resultVO.setCode(businessException.getErrorCode());
            resultVO.setMessage(businessException.getErrorMessage());
        }
        return resultVO;
    }

}
