package com.nx.umms.common.utils.res;

/**
 * @Auther: wangjian
 * @Date: 2022/3/28 17:13
 * @Description:定义状态码枚举值
 */
public enum ResultCodeEnum {

    /**
     * 操作成功
     **/
    SUCCESS(200, "操作成功", true),

    /**
     * 操作失败
     **/
    RC999(999, "操作失败", false),

    /**
     * 服务限流
     **/
    RC200(200, "服务开启限流保护,请稍后再试!", false),

    /**
     * 服务降级
     **/
    RC201(201, "服务开启降级保护,请稍后再试!", false),

    /**
     * 热点参数限流
     **/
    RC202(202, "热点参数限流,请稍后再试!", false),

    /**
     * 系统规则不满足
     **/
    RC203(203, "系统规则不满足要求,请稍后再试!", false),

    /**
     * 授权规则不通过
     **/
    RC204(204, "授权规则不通过,请稍后再试!", false),

    /**
     * access_denied
     **/
    RC403(403, "无访问权限,请联系管理员授予权限", false),

    /**
     * access_denied
     **/
    RC401(401, "匿名用户访问无权限资源时的异常", false),

    /**
     * 系统异常
     */
    INTERNAL_SERVER_ERROR(500, "系统异常，请稍后重试", false),

    INVALID_TOKEN(2001, "访问令牌不合法", false),
    ACCESS_DENIED(2003, "没有权限访问该资源", false),
    CLIENT_AUTHENTICATION_FAILED(1001, "客户端认证失败", false),
    USERNAME_OR_PASSWORD_ERROR(1002, "用户名或密码错误", false),
    UNSUPPORTED_GRANT_TYPE(1003, "不支持的认证模式", false),

    /**
     * 必填参数为空
     */
    REQUIRED_PARAMETER_EMPTY(0, "必填参数为空", false),

    /**
     * 参数类型错误
     */
    PARAMETER_TYPE_ERROR(0, "Parameter type error", false),

    /**
     * 未登录
     */
    NOT_LOGIN(401001, "用户未登录", false),

    /**
     * 用户名或密码错误
     */
    LOGIN_FAIL(401002, "用户名或密码错误", false),

    /**
     * 无权限访问
     */
    NO_PERMISSION(401003, "无权限访问", false),

    /**
     * 系统异常
     */
    UNKNOWN(9999, "System abnormal", false),

    /**
     * 数据异常
     */
    NO_DATA(200, "数据库无数据", false),

    UP_DATA_FAIL(401005, "更新失败", false),

    INSERT_FAIL(401006, "插入数据失败", false),

    DELETE_FAIL(401007, "修改失败", false),

    DATA_REPETITION(250, "分类编码或分类名称重复", false),


    /* ============================ 文件处理 错误码 ========================== **/
    FILE_NOT_EXISTS(21001, "文件不存在", false),
    FILE_MUST_IS_EXCEL(21002, "文件类型必须是excel", false),
    UPLOAD_EXCEPTION(21003, "上传过程出现异常", false),
    EXCEL_RULE_NOT_EXISTS(21004, "excel校验规则不存在", false),
    EXCEL_TEMPLATE_NOT_EXISTS(21005, "excel模板不存在", false),
    EXCEL_TEMPLATE_NOT_CORRECT(21009, "excel模板不对，请重新下载", false),
    EXCEL_DATA_NOT_EXISTS(21006, "excle数据不存在", false),
    EXCEL_NOT_CORRECT(21007, "excel不正确", false),
    EXCEL_PARSE_CORRECT(21010, "excel解析错误", false),
    CURRENT_MONTH_NOT_EXISTS(21008, "当前年月数据不存在", false),
    BATCH_NOT_NEED(21009, "无需批量操作！", false),
    CELL_IS_NULL(21010, "值不能为空", false),
    CELL_FORMAT_ERROR(21011, "值格式不正确", false),
    CELL_MIN_LENGTH_ERROR(21012, "值小于最小长度", false),
    CELL_MAX_LENGTH_ERROR(21013, "值大于最大长度", false),
    CELL_REGULAR_ERROR(21014, "值正则验证不通过", false),
    CELL_OPTION_ERROR(21015, "值不在选项集范围内", false),
    ROW_DUPLICATE_ERROR(21016, "行重复性校验未通过", false),
    CELL_DATE_FORMAT_ERROR(21017, "日期范围格式不正确", false),

    DATA_MISSING_UNITS(21018, "数据缺少单位级别编码", false),
    PICTURE_NAME_ILLEGAL(21019, "图片名称不合法,请重新上传", false),
    FILE_MUST_IS_PIC(21020, "图片格式不合法,请重新上传!", false),
    NAME_CONFLICT(21021, "该组织机构下名称重复,请修改名称!", false),
    ENCRYPT_ERROR_CODE(21022, "解密失败", false),

    /* ===========================后台系统======================== **/
    RECORD_NOT_EXIST(10001, "相关记录不存在!", false),
    SYS_USER_INVALID(10002, "用户登录已过期!", false),
    PERMISSION_NOT(10003, "无访问权限!", false),
    ACCOUNT_NOT(10004, "账号异常!", false),
    SHIRO_ERROR(10005, "鉴权/授权过程出错!", false),
    MENU_EXIST(10006, "菜单定义已存在！", false),
    ROLE_EXIST(10007, "角色定义已存在！", false),
    CODE_EXIST(10008, "编码已存在！", false),
    NAME_EXIST(10009, "名称已存在!", false),
    NO_DELETE(10010, "无法删除，有关联数据!", false),
    NO_REQUEST_DATA(10011, "前端未传入分类编码!", false),
    USER_ORGANIZATION_LEVEL_ERROR(10023, "用户组织机构关联层级有误！", false),
    USER_ORGANIZATION_INFO_ERROR(10024, "用户组织机构信息有误！", false),
    TOKEN_INVALID(9997, "登录失效，请重新登录！", false);

    /**
     * 自定义状态码
     **/
    private final int code;

    /**
     * 自定义描述
     **/
    private final Boolean status;

    /**
     * 自定义描述
     **/
    private final String message;

    ResultCodeEnum(int code, String message, boolean status) {
        this.code = code;
        this.message = message;
        this.status = status;
    }

    public int getCode() {
        return code;
    }

    public String getMessage() {
        return message;
    }

    public Boolean getStatus() {
        return status;
    }
}
