package com.nx.umms.common.utils.res;

import io.swagger.annotations.ApiModel;
import lombok.Data;

/**
 * @Auther: wangjian
 * @Date: 2022/3/28 17:09
 * @Description:统一返回对象
 */

@ApiModel(value = "返回对象", description = "返回对象")
@Data
public class ResultVO<T> {

//    code 状态值：由后端统一定义各种返回结果的状态码
//    message 描述：本次接口调用的结果描述
//    data 数据：本次返回的数据。

    /**
     * 结果状态 ,具体状态码参见ResultData.java
     */
    private Integer code;

    /**
     * 描述：本次接口调用的结果描述
     */
    private String message;

    private boolean status;

    /**
     * 数据：本次返回的数据
     */
    private T data;

    /**
     * 接口调用时间
     */
    private Long timestamp;


    public ResultVO() {
        this.timestamp = System.currentTimeMillis();
    }

    public ResultVO(ResultCodeEnum codeEnum) {
        this.setCode(codeEnum.getCode());
        this.setMessage(codeEnum.getMessage());
        this.setStatus(codeEnum.getStatus());
    }

    public static <T> ResultVO<T> success() {
        return new ResultVO<>(ResultCodeEnum.SUCCESS);
    }

    public static <T> ResultVO<T> success(T data) {
        ResultVO<T> resultVO = new ResultVO<>();
        resultVO.setCode(ResultCodeEnum.SUCCESS.getCode());
        resultVO.setMessage(ResultCodeEnum.SUCCESS.getMessage());
        resultVO.setStatus(ResultCodeEnum.SUCCESS.getStatus());
        resultVO.setData(data);
        return resultVO;
    }

    public static <T> ResultVO<T> fail(int code, String message, boolean status) {
        ResultVO<T> resultVO = new ResultVO<>();
        resultVO.setCode(code);
        resultVO.setMessage(message);
        resultVO.setStatus(status);
        return resultVO;
    }

    public static <T> ResultVO<T> fail(ResultCodeEnum resultCodeEnum, String message) {
        int code = resultCodeEnum.getCode();
        boolean status = resultCodeEnum.getStatus();
        return fail(code, message, status);
    }

    public static <T> ResultVO<T> fail(ResultCodeEnum resultCodeEnum) {
        return new ResultVO<T>(resultCodeEnum);
    }

    public void setResultCodeEnum(ResultCodeEnum resultCodeEnum) {
        this.code = resultCodeEnum.getCode();
        this.message = resultCodeEnum.getMessage();
        this.status = resultCodeEnum.getStatus();
    }

}

