package com.nx.umms.controller;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.nx.umms.common.utils.DataHandleUtils;
import com.nx.umms.common.utils.res.ResultCodeEnum;
import com.nx.umms.common.utils.res.ResultVO;
import com.nx.umms.model.dto.ModelVersionDTO;
import com.nx.umms.model.entity.ModelVersion;
import com.nx.umms.model.vo.ModelVersionVO;
import com.nx.umms.service.ModelVersionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @Auther: wangjian
 * @Date: 2022/3/25 15:25
 * @Description:模型发布管理接口
 */

@Slf4j
@RequestMapping("/model-issue/v1")
@RestController
@Api(tags = "模型发布管理接口")
public class ModelIssueManageController {

    @Autowired
    private ModelVersionService modelVersionService;


    /**
     * 模型版本-增加
     *
     * @return
     */
    @ApiOperation("模型版本-增加")
    @PostMapping("/create/modelVersion")
    public ResultVO createModelVersion(@RequestBody ModelVersionDTO modelVersionDTO) {

        if (DataHandleUtils.isNullOrEmpty(modelVersionDTO)) {
            ResultVO.fail(ResultCodeEnum.REQUIRED_PARAMETER_EMPTY);
        }

        return ResultVO.success(modelVersionService.createModelVersion(modelVersionDTO));
    }

    /**
     * 模型版本-查询列表
     *
     * @return
     */
    @ApiOperation("模型版本-查询列表")
    @GetMapping("/get/modelVersion/list")
    public ResultVO getModelVersionList(@ApiParam(value = "模型版本编号") @RequestParam(value = "mvId", required = false) String mvId,
                                        @ApiParam(value = "模型版本编码") @RequestParam(value = "versionCode", required = false) String versionCode,
                                        @ApiParam(value = "当前页") @RequestParam(value = "currentPage") Integer currentPage,
                                        @ApiParam(value = "每页数量") @RequestParam(value = "pageSize") Integer pageSize) {

        PageHelper.startPage(currentPage, pageSize);
        List<ModelVersionVO> modelVersionVOList = modelVersionService.getModelVersionList(mvId, versionCode);
        PageInfo<ModelVersionVO> pageInfo = new PageInfo<>(modelVersionVOList);
//        return ResultData(pageInfo);
        return ResultVO.success(pageInfo);
    }

    /**
     * 模型版本-查询
     *
     * @return
     */
    @ApiOperation("模型版本-查询")
    @GetMapping("/get/modelVersion")
    public ResultVO getModelVersion(@ApiParam(value = "模型版本编号") @RequestParam(value = "mvId", required = false) String mvId,
                                    @ApiParam(value = "模型版本号") @RequestParam(value = "versionNumber", required = false) String versionNumber) {

        ModelVersion modelVersion = modelVersionService.getModelVersion(mvId, versionNumber);

        if (modelVersion == null) {
            return ResultVO.success(ResultCodeEnum.NO_DATA);
        }

        ModelVersionVO modelVersionVO = new ModelVersionVO();
        BeanUtils.copyProperties(modelVersion, modelVersionVO);
        return ResultVO.success(modelVersionVO);
    }

    /**
     * 模型版本-删除
     *
     * @return
     */
    @ApiOperation("模型版本-删除")
    @PostMapping("/delete/modelVersion")
    public ResultVO deleteModelVersion(@ApiParam(value = "模型版本编号") @RequestParam(value = "mvId", required = false) String mvId,
                                       @ApiParam(value = "版本编码") @RequestParam(value = "versionCode", required = false) String versionCode) {
        return ResultVO.success(modelVersionService.deleteModelVersion(mvId, versionCode));
    }

    /**
     * 模型版本-修改
     *
     * @return
     */
    @ApiOperation("模型版本-修改")
    @PostMapping("/update/modelVersion")
    public ResultVO updateModel(@RequestBody ModelVersionDTO modelVersionDTO) {
        if (DataHandleUtils.isNullOrEmpty(modelVersionDTO)) {
            ResultVO.fail(ResultCodeEnum.ACCESS_DENIED.REQUIRED_PARAMETER_EMPTY);
        }
        return ResultVO.success(modelVersionService.updateModelVersion(modelVersionDTO));
    }

//    /**
//     * 模型版本-查询列表
//     *
//     * @return
//     */
//    @ApiOperation("模型版本-查询")
//    @GetMapping("/get/model/list")
//    public ResultVO getModelList(@ApiParam(value = "模型订阅编号") @RequestParam(value = "objId", required = false) String objId,
//                                   @ApiParam(value = "模型编码") @RequestParam(value = "modelCode", required = false) String modelCode,
//                                   @ApiParam(value = "归属省编码数组EQ: ddas232, 2e1ssda, 3232") @RequestParam(value = "ownerCompanyCodes", required = false) List<String> ownerCompanyCodes,
//                                   @ApiParam(value = "归属分类编码数组") @RequestParam(value = "modelGroupCodes", required = false) List<String> modelGroupCodes,
//                                   @ApiParam(value = "当前页") @RequestParam(value = "currentPage", required = false) Integer currentPage,
//                                   @ApiParam(value = "每页数量") @RequestParam(value = "pageSize", required = false) Integer pageSize) {
//
//        PageHelper.startPage(currentPage, pageSize);
//        List<Model> modelList = modelService.getModelList(objId, modelCode, ownerCompanyCodes, modelGroupCodes);
//        PageInfo<Model> pageInfo = new PageInfo<>(modelList);
//        return ResultVO.ok(pageInfo);
//    }

}

